@@ -6,9 +6,9 @@ Type annotations for workmail service literal definitions.
 Usage::
 
     ```python
-    from mypy_boto3_workmail.literals import AccessControlRuleEffect
+    from mypy_boto3_workmail.literals import AccessControlRuleEffectType
 
-    data: AccessControlRuleEffect = "ALLOW"
+    data: AccessControlRuleEffectType = "ALLOW"
     ```
 """
 import sys
@@ -20,9 +20,9 @@ else:
 
 
 __all__ = (
-    "AccessControlRuleEffect",
-    "EntityState",
-    "FolderName",
+    "AccessControlRuleEffectType",
+    "EntityStateType",
+    "FolderNameType",
     "ListAliasesPaginatorName",
     "ListGroupMembersPaginatorName",
     "ListGroupsPaginatorName",
@@ -31,19 +31,19 @@ __all__ = (
     "ListResourceDelegatesPaginatorName",
     "ListResourcesPaginatorName",
     "ListUsersPaginatorName",
-    "MailboxExportJobState",
-    "MemberType",
-    "MobileDeviceAccessRuleEffect",
-    "PermissionType",
-    "ResourceType",
-    "RetentionAction",
-    "UserRole",
+    "MailboxExportJobStateType",
+    "MemberTypeType",
+    "MobileDeviceAccessRuleEffectType",
+    "PermissionTypeType",
+    "ResourceTypeType",
+    "RetentionActionType",
+    "UserRoleType",
 )
 
 
-AccessControlRuleEffect = Literal["ALLOW", "DENY"]
-EntityState = Literal["DELETED", "DISABLED", "ENABLED"]
-FolderName = Literal["DELETED_ITEMS", "DRAFTS", "INBOX", "JUNK_EMAIL", "SENT_ITEMS"]
+AccessControlRuleEffectType = Literal["ALLOW", "DENY"]
+EntityStateType = Literal["DELETED", "DISABLED", "ENABLED"]
+FolderNameType = Literal["DELETED_ITEMS", "DRAFTS", "INBOX", "JUNK_EMAIL", "SENT_ITEMS"]
 ListAliasesPaginatorName = Literal["list_aliases"]
 ListGroupMembersPaginatorName = Literal["list_group_members"]
 ListGroupsPaginatorName = Literal["list_groups"]
@@ -52,10 +52,10 @@ ListOrganizationsPaginatorName = Literal["list_organizations"]
 ListResourceDelegatesPaginatorName = Literal["list_resource_delegates"]
 ListResourcesPaginatorName = Literal["list_resources"]
 ListUsersPaginatorName = Literal["list_users"]
-MailboxExportJobState = Literal["CANCELLED", "COMPLETED", "FAILED", "RUNNING"]
-MemberType = Literal["GROUP", "USER"]
-MobileDeviceAccessRuleEffect = Literal["ALLOW", "DENY"]
-PermissionType = Literal["FULL_ACCESS", "SEND_AS", "SEND_ON_BEHALF"]
-ResourceType = Literal["EQUIPMENT", "ROOM"]
-RetentionAction = Literal["DELETE", "NONE", "PERMANENTLY_DELETE"]
-UserRole = Literal["RESOURCE", "SYSTEM_USER", "USER"]
+MailboxExportJobStateType = Literal["CANCELLED", "COMPLETED", "FAILED", "RUNNING"]
+MemberTypeType = Literal["GROUP", "USER"]
+MobileDeviceAccessRuleEffectType = Literal["ALLOW", "DENY"]
+PermissionTypeType = Literal["FULL_ACCESS", "SEND_AS", "SEND_ON_BEHALF"]
+ResourceTypeType = Literal["EQUIPMENT", "ROOM"]
+RetentionActionType = Literal["DELETE", "NONE", "PERMANENTLY_DELETE"]
+UserRoleType = Literal["RESOURCE", "SYSTEM_USER", "USER"]
